@@ -21,7 +21,6 @@ from xml.etree import ElementTree as ET
 
 from slixmpp.xmlstream import JID
 from slixmpp.xmlstream.tostring import tostring
-from collections import OrderedDict
 
 
 log = logging.getLogger(__name__)
@@ -392,7 +391,7 @@ class ElementBase(object):
 
         #: An ordered dictionary of plugin stanzas, mapped by their
         #: :attr:`plugin_attrib` value.
-        self.plugins = OrderedDict()
+        self.plugins = {}
         self.loaded_plugins = set()
 
         #: A list of child stanzas whose class is included in
@@ -541,7 +540,7 @@ class ElementBase(object):
 
         .. versionadded:: 1.0-Beta1
         """
-        values = OrderedDict()
+        values = {}
         values['lang'] = self['lang']
         for interface in self.interfaces:
             if isinstance(self[interface], JID):
@@ -726,8 +725,6 @@ class ElementBase(object):
         if lang and attrib in self.lang_interfaces:
             kwargs['lang'] = lang
 
-        kwargs = OrderedDict(kwargs)
-
         if attrib in self.interfaces or attrib == 'lang':
             if value is not None:
                 set_method = "set_%s" % attrib.lower()
@@ -745,6 +742,8 @@ class ElementBase(object):
                     getattr(self, set_method)(value, **kwargs)
                 else:
                     if attrib in self.sub_interfaces:
+                        if isinstance(value, JID):
+                            value = str(value)
                         if lang == '*':
                             return self._set_all_sub_text(attrib,
                                                           value,
@@ -811,8 +810,6 @@ class ElementBase(object):
         if lang and attrib in self.lang_interfaces:
             kwargs['lang'] = lang
 
-        kwargs = OrderedDict(kwargs)
-
         if attrib in self.interfaces or attrib == 'lang':
             del_method = "del_%s" % attrib.lower()
 
@@ -863,6 +860,8 @@ class ElementBase(object):
         if value is None or value == '':
             self.__delitem__(name)
         else:
+            if isinstance(value, JID):
+                value = str(value)
             self.xml.attrib[name] = value
 
     def _del_attr(self, name):
@@ -925,7 +924,7 @@ class ElementBase(object):
         name = self._fix_ns(name)
 
         default_lang = self.get_lang()
-        results = OrderedDict()
+        results = {}
         stanzas = self.xml.findall(name)
         if stanzas:
             for stanza in stanzas:
@@ -1497,12 +1496,7 @@ class StanzaBase(ElementBase):
                                                       self.name)
 
     def send(self):
-        """Queue the stanza to be sent on the XML stream.
-
-        :param bool now: Indicates if the queue should be skipped and the
-                         stanza sent immediately. Useful for stream
-                         initialization. Defaults to ``False``.
-        """
+        """Queue the stanza to be sent on the XML stream."""
         self.stream.send(self)
 
     def __copy__(self):
