@@ -7,7 +7,7 @@
 """
 
 from slixmpp.xmlstream.stanzabase import ElementBase
-from xml.etree import cElementTree as ET
+from xml.etree import ElementTree as ET
 
 
 class RPCQuery(ElementBase):
