@@ -1,7 +1,7 @@
 """
     Slixmpp: The Slick XMPP Library
-    Copyright (C) 2012 Nathanael C. Fritz,
-                       Emmanuel Gil Peyrot <linkmauve@linkmauve.fr>
+    Copyright (C) 2012 Nathanael C. Fritz
+    Emmanuel Gil Peyrot <linkmauve@linkmauve.fr>
     This file is part of Slixmpp.
 
     See the file LICENSE for copying permission.
@@ -18,7 +18,7 @@ class BitsOfBinary(ElementBase):
     name = 'data'
     namespace = 'urn:xmpp:bob'
     plugin_attrib = 'bob'
-    interfaces = set(('cid', 'max_age', 'type', 'data'))
+    interfaces = {'cid', 'max_age', 'type', 'data'}
 
     def get_max_age(self):
         return int(self._get_attr('max-age'))
